
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.21.0rc2',
    'branch_nick': 'feature-0-Release__1_21_0rc2_preparation',
    'revision_id': '5692d34509a92c52a0252f578460555345027ab6',
    'revno': 8941
}
